Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
Verbosity com.Level = com.Common
)
Functions ¶
This section is empty.
Types ¶
type Difference ¶
Difference holds information like detected changes and stats.
type FileInfo ¶
type FileInfo struct {
Mtime time.Time
Permissions os.FileMode
Size int64
Owner uint32
Group uint32
Hash []byte
}
FileInfo holds meta data about a regular file.
type Root ¶
type Root struct {
// contains filtered or unexported fields
}
Root is the store.
func (*Root) Compare ¶
func (r *Root) Compare() (Difference, error)
Compare triggers an additional scan of the files in the directory tree and notifies if it detects changes.
Click to show internal directories.
Click to hide internal directories.